drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx |   37 ++--
 filter/source/pdf/impdialog.cxx                            |   12 -
 filter/source/pdf/impdialog.hxx                            |    2 
 filter/source/pdf/pdfexport.cxx                            |   92 +++++-----
 filter/source/pdf/pdfexport.hxx                            |   10 -
 filter/source/pdf/pdfinteract.cxx                          |    4 
 include/vcl/formpdfexport.hxx                              |    2 
 include/vcl/pdfextoutdevdata.hxx                           |   18 -
 include/vcl/pdfwriter.hxx                                  |   20 +-
 sd/source/ui/unoidl/unomodel.cxx                           |   44 ++--
 sw/source/core/text/EnhancedPDFExportHelper.cxx            |  118 ++++++-------
 sw/source/core/text/itrform2.cxx                           |   24 +-
 sw/source/core/text/porfld.cxx                             |    2 
 vcl/source/filter/ipdf/pdfdocument.cxx                     |    2 
 vcl/source/gdi/formpdfexport.cxx                           |   48 ++---
 vcl/source/pdf/pdfextoutdevdata.cxx                        |   46 ++---
 vcl/unx/generic/print/genprnpsp.cxx                        |   14 -
 17 files changed, 248 insertions(+), 247 deletions(-)

New commits:
commit 500442846fa6f486a06f7104f78263fa8eb433db
Author:     Christopher Sherlock <[email protected]>
AuthorDate: Sun Oct 12 16:59:43 2025 +1100
Commit:     Tomaž Vajngerl <[email protected]>
CommitDate: Thu Oct 23 06:53:27 2025 +0200

    vcl: move PDFWriter into vcl::pdf namespace
    
    Change-Id: If2ceabafc72ed1d719876778de3d48511203e045
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/192287
    Tested-by: Jenkins
    Reviewed-by: Tomaž Vajngerl <[email protected]>

diff --git a/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx 
b/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
index 4188e32e0f1b..dfe22459e428 100644
--- a/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
+++ b/drawinglayer/source/processor2d/vclmetafileprocessor2d.cxx
@@ -1229,7 +1229,7 @@ void VclMetafileProcessor2D::processControlPrimitive2D(
     if (bPDFExport && !bDecorative)
     {
         // PDF export. Emulate data handling from UnoControlPDFExportContact
-        std::unique_ptr<vcl::PDFWriter::AnyWidget> pPDFControl(
+        std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> pPDFControl(
             ::toolkitform::describePDFControl(rXControl, *mpPDFExtOutDevData));
 
         if (pPDFControl)
@@ -1249,24 +1249,24 @@ void VclMetafileProcessor2D::processControlPrimitive2D(
             pPDFControl->TextFont.SetFontSize(aFontSize);
 
             
mpPDFExtOutDevData->WrapBeginStructureElement(vcl::pdf::StructElement::Form);
-            vcl::PDFWriter::StructAttributeValue role;
+            vcl::pdf::PDFWriter::StructAttributeValue role;
             switch (pPDFControl->Type)
             {
-                case vcl::PDFWriter::PushButton:
-                    role = vcl::PDFWriter::Pb;
+                case vcl::pdf::PDFWriter::PushButton:
+                    role = vcl::pdf::PDFWriter::Pb;
                     break;
-                case vcl::PDFWriter::RadioButton:
-                    role = vcl::PDFWriter::Rb;
+                case vcl::pdf::PDFWriter::RadioButton:
+                    role = vcl::pdf::PDFWriter::Rb;
                     break;
-                case vcl::PDFWriter::CheckBox:
-                    role = vcl::PDFWriter::Cb;
+                case vcl::pdf::PDFWriter::CheckBox:
+                    role = vcl::pdf::PDFWriter::Cb;
                     break;
                 default: // there is a paucity of roles, tv is the catch-all 
one
-                    role = vcl::PDFWriter::Tv;
+                    role = vcl::pdf::PDFWriter::Tv;
                     break;
             }
             // ISO 14289-1:2014, Clause: 7.18.4
-            mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Role, 
role);
+            
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Role, role);
             // ISO 14289-1:2014, Clause: 7.18.1
             OUString const& rAltText(rControlPrimitive.GetAltText());
             if (!rAltText.isEmpty())
@@ -1304,7 +1304,8 @@ void VclMetafileProcessor2D::processControlPrimitive2D(
         else
             mpPDFExtOutDevData->WrapBeginStructureElement(
                 vcl::pdf::StructElement::NonStructElement);
-        mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Placement, 
vcl::PDFWriter::Block);
+        
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Placement,
+                                                  vcl::pdf::PDFWriter::Block);
         auto const 
range(rControlPrimitive.getB2DRange(getViewInformation2D()));
         tools::Rectangle const 
aLogicRect(basegfx::fround<tools::Long>(range.getMinX()),
                                           
basegfx::fround<tools::Long>(range.getMinY()),
@@ -1440,7 +1441,7 @@ void 
VclMetafileProcessor2D::processTextHierarchyFieldPrimitive2D(
 
     if (bIsExportTaggedPDF)
     {
-        
mpPDFExtOutDevData->SetStructureAttributeNumerical(vcl::PDFWriter::LinkAnnotation,
+        
mpPDFExtOutDevData->SetStructureAttributeNumerical(vcl::pdf::PDFWriter::LinkAnnotation,
                                                            aBookmark.nLinkId);
         mpPDFExtOutDevData->EndStructureElement();
     }
@@ -2759,13 +2760,13 @@ void 
VclMetafileProcessor2D::processStructureTagPrimitive2D(
                 case vcl::pdf::StructElement::Formula:
                 case vcl::pdf::StructElement::Figure:
                 case vcl::pdf::StructElement::Annot:
-                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Placement,
-                                                              
vcl::PDFWriter::Block);
+                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Placement,
+                                                              
vcl::pdf::PDFWriter::Block);
                     break;
                 case vcl::pdf::StructElement::TableData:
                 case vcl::pdf::StructElement::TableHeader:
-                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Placement,
-                                                              
vcl::PDFWriter::Inline);
+                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Placement,
+                                                              
vcl::pdf::PDFWriter::Inline);
                     break;
                 default:
                     break;
@@ -2795,8 +2796,8 @@ void 
VclMetafileProcessor2D::processStructureTagPrimitive2D(
             }
             if (rTagElement == vcl::pdf::StructElement::TableHeader)
             {
-                
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Scope,
-                                                          
vcl::PDFWriter::Column);
+                
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Scope,
+                                                          
vcl::pdf::PDFWriter::Column);
             }
         }
         // background object
diff --git a/filter/source/pdf/impdialog.cxx b/filter/source/pdf/impdialog.cxx
index 108291f21ddd..55f98e2d81b2 100644
--- a/filter/source/pdf/impdialog.cxx
+++ b/filter/source/pdf/impdialog.cxx
@@ -1740,7 +1740,7 @@ IMPL_LINK_NOARG(ImpPDFTabLinksPage, 
ClickRbOpnLnksBrowserHdl, weld::Toggleable&,
     mbOpnLnksRemoveUserState = m_xRbOpnLnksRemove->get_active();
 }
 
-ImplErrorDialog::ImplErrorDialog(weld::Window* pParent, const 
std::set<vcl::PDFWriter::ErrorCode>& rErrors)
+ImplErrorDialog::ImplErrorDialog(weld::Window* pParent, const 
std::set<vcl::pdf::PDFWriter::ErrorCode>& rErrors)
     : MessageDialogController(pParent, u"filter/ui/warnpdfdialog.ui"_ustr, 
u"WarnPDFDialog"_ustr, u"grid"_ustr)
     , m_xErrors(m_xBuilder->weld_tree_view(u"errors"_ustr))
     , m_xExplanation(m_xBuilder->weld_label(u"message"_ustr))
@@ -1754,19 +1754,19 @@ ImplErrorDialog::ImplErrorDialog(weld::Window* pParent, 
const std::set<vcl::PDFW
     {
         switch(error)
         {
-        case vcl::PDFWriter::Warning_Transparency_Omitted_PDFA:
+        case vcl::pdf::PDFWriter::Warning_Transparency_Omitted_PDFA:
             m_xErrors->append(FilterResId(STR_WARN_TRANSP_PDFA), 
FilterResId(STR_WARN_TRANSP_PDFA_SHORT), u"dialog-warning"_ustr);
             break;
-        case vcl::PDFWriter::Warning_Transparency_Omitted_PDF13:
+        case vcl::pdf::PDFWriter::Warning_Transparency_Omitted_PDF13:
             m_xErrors->append(FilterResId(STR_WARN_TRANSP_VERSION), 
FilterResId(STR_WARN_TRANSP_VERSION_SHORT), u"dialog-warning"_ustr);
             break;
-        case vcl::PDFWriter::Warning_FormAction_Omitted_PDFA:
+        case vcl::pdf::PDFWriter::Warning_FormAction_Omitted_PDFA:
             m_xErrors->append(FilterResId(STR_WARN_FORMACTION_PDFA), 
FilterResId(STR_WARN_FORMACTION_PDFA_SHORT), u"dialog-warning"_ustr);
             break;
-        case vcl::PDFWriter::Warning_Transparency_Converted:
+        case vcl::pdf::PDFWriter::Warning_Transparency_Converted:
             m_xErrors->append(FilterResId(STR_WARN_TRANSP_CONVERTED), 
FilterResId(STR_WARN_TRANSP_CONVERTED_SHORT), u"dialog-warning"_ustr);
             break;
-        case vcl::PDFWriter::Error_Signature_Failed:
+        case vcl::pdf::PDFWriter::Error_Signature_Failed:
             m_xErrors->append(FilterResId(STR_ERR_PDF_EXPORT_ABORTED), 
FilterResId(STR_ERR_SIGNATURE_FAILED), u"dialog-error"_ustr);
             break;
         default:
diff --git a/filter/source/pdf/impdialog.hxx b/filter/source/pdf/impdialog.hxx
index 625b662ef8e8..47da48949c91 100644
--- a/filter/source/pdf/impdialog.hxx
+++ b/filter/source/pdf/impdialog.hxx
@@ -46,7 +46,7 @@ private:
     DECL_LINK(SelectHdl, weld::TreeView&, void);
 
 public:
-    explicit ImplErrorDialog(weld::Window* pParent, const 
std::set<vcl::PDFWriter::ErrorCode>& rErrorCodes);
+    explicit ImplErrorDialog(weld::Window* pParent, const 
std::set<vcl::pdf::PDFWriter::ErrorCode>& rErrorCodes);
 };
 
 
diff --git a/filter/source/pdf/pdfexport.cxx b/filter/source/pdf/pdfexport.cxx
index 53b21902ba4d..f1b047576f4b 100644
--- a/filter/source/pdf/pdfexport.cxx
+++ b/filter/source/pdf/pdfexport.cxx
@@ -109,7 +109,7 @@ PDFExport::~PDFExport()
 }
 
 
-bool PDFExport::ExportSelection( vcl::PDFWriter& rPDFWriter,
+bool PDFExport::ExportSelection( vcl::pdf::PDFWriter& rPDFWriter,
     Reference< css::view::XRenderable > const & rRenderable,
     const Any& rSelection,
     const StringRangeEnumerator& rRangeEnum,
@@ -387,7 +387,7 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
     INetURLObject   aURL( rFile );
     bool        bRet = false;
 
-    std::set< vcl::PDFWriter::ErrorCode > aErrors;
+    std::set< vcl::pdf::PDFWriter::ErrorCode > aErrors;
 
     if( aURL.GetProtocol() != INetProtocol::File )
     {
@@ -454,7 +454,7 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             rtl::Reference<VCLXDevice>  xDevice(new VCLXDevice);
             OUString                    aPageRange;
             Any                         aSelection;
-            vcl::PDFWriter::PDFWriterContext aContext;
+            vcl::pdf::PDFWriter::PDFWriterContext aContext;
             OUString aOpenPassword, aPermissionPassword;
             Reference< beans::XMaterialHolder > xEnc;
             Sequence< beans::NamedValue > aPreparedPermissionPassword;
@@ -760,24 +760,24 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             {
             default:
             case 0:
-                aContext.Version = vcl::PDFWriter::PDFVersion::Default;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::Default;
                 break;
             case 1:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_A_1;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_A_1;
                 bUseTaggedPDF = true;           // force the tagged PDF as well
                 mbRemoveTransparencies = true;  // does not allow 
transparencies
                 bEncrypt = false;               // no encryption
                 xEnc.clear();
                 break;
             case 2:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_A_2;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_A_2;
                 bUseTaggedPDF = true;           // force the tagged PDF as well
                 mbRemoveTransparencies = false; // does allow transparencies
                 bEncrypt = false;               // no encryption
                 xEnc.clear();
                 break;
             case 3:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_A_3;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_A_3;
                 bUseTaggedPDF = true;           // force the tagged PDF as well
                 mbRemoveTransparencies = false; // does allow transparencies
                 bEncrypt = false;               // no encryption
@@ -785,23 +785,23 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
                 break;
             case 4:
                 // TODO - determine what is allowed for PDFA/4
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_A_4;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_A_4;
                 bUseTaggedPDF = true;           // force the tagged PDF as well
                 mbRemoveTransparencies = false; // does allow transparencies
                 bEncrypt = false;               // no encryption
                 xEnc.clear();
                 break;
             case 15:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_1_5;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_1_5;
                 break;
             case 16:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_1_6;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_1_6;
                 break;
             case 17:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_1_7;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_1_7;
                 break;
             case 20:
-                aContext.Version = vcl::PDFWriter::PDFVersion::PDF_2_0;
+                aContext.Version = vcl::pdf::PDFWriter::PDFVersion::PDF_2_0;
                 break;
             }
 
@@ -835,32 +835,32 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             {
                 default:
                 case 0:
-                    aContext.PDFDocumentMode = vcl::PDFWriter::ModeDefault;
+                    aContext.PDFDocumentMode = 
vcl::pdf::PDFWriter::ModeDefault;
                     break;
                 case 1:
-                    aContext.PDFDocumentMode = vcl::PDFWriter::UseOutlines;
+                    aContext.PDFDocumentMode = 
vcl::pdf::PDFWriter::UseOutlines;
                     break;
                 case 2:
-                    aContext.PDFDocumentMode = vcl::PDFWriter::UseThumbs;
+                    aContext.PDFDocumentMode = vcl::pdf::PDFWriter::UseThumbs;
                     break;
             }
             switch( nPDFDocumentAction )
             {
                 default:
                 case 0:
-                    aContext.PDFDocumentAction = vcl::PDFWriter::ActionDefault;
+                    aContext.PDFDocumentAction = 
vcl::pdf::PDFWriter::ActionDefault;
                     break;
                 case 1:
-                    aContext.PDFDocumentAction = vcl::PDFWriter::FitInWindow;
+                    aContext.PDFDocumentAction = 
vcl::pdf::PDFWriter::FitInWindow;
                     break;
                 case 2:
-                    aContext.PDFDocumentAction = vcl::PDFWriter::FitWidth;
+                    aContext.PDFDocumentAction = vcl::pdf::PDFWriter::FitWidth;
                     break;
                 case 3:
-                    aContext.PDFDocumentAction = vcl::PDFWriter::FitVisible;
+                    aContext.PDFDocumentAction = 
vcl::pdf::PDFWriter::FitVisible;
                     break;
                 case 4:
-                    aContext.PDFDocumentAction = vcl::PDFWriter::ActionZoom;
+                    aContext.PDFDocumentAction = 
vcl::pdf::PDFWriter::ActionZoom;
                     aContext.Zoom = nZoom;
                     break;
             }
@@ -869,23 +869,23 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             {
                 default:
                 case 0:
-                    aContext.PageLayout = vcl::PDFWriter::DefaultLayout;
+                    aContext.PageLayout = vcl::pdf::PDFWriter::DefaultLayout;
                     break;
                 case 1:
-                    aContext.PageLayout = vcl::PDFWriter::SinglePage;
+                    aContext.PageLayout = vcl::pdf::PDFWriter::SinglePage;
                     break;
                 case 2:
-                    aContext.PageLayout = vcl::PDFWriter::Continuous;
+                    aContext.PageLayout = vcl::pdf::PDFWriter::Continuous;
                     break;
                 case 3:
-                    aContext.PageLayout = vcl::PDFWriter::ContinuousFacing;
+                    aContext.PageLayout = 
vcl::pdf::PDFWriter::ContinuousFacing;
                     break;
             }
 
             aContext.FirstPageLeft = false;
 
             // check if PDF/A, which does not allow encryption
-            if( aContext.Version != vcl::PDFWriter::PDFVersion::PDF_A_1 )
+            if( aContext.Version != vcl::pdf::PDFWriter::PDFVersion::PDF_A_1 )
             {
                 // set check for permission change password
                 // if not enabled and no permission password, force 
permissions to default as if PDF where without encryption
@@ -957,17 +957,17 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             switch( nFormsFormat )
             {
                 case 1:
-                    aContext.SubmitFormat = vcl::PDFWriter::PDF;
+                    aContext.SubmitFormat = vcl::pdf::PDFWriter::PDF;
                     break;
                 case 2:
-                    aContext.SubmitFormat = vcl::PDFWriter::HTML;
+                    aContext.SubmitFormat = vcl::pdf::PDFWriter::HTML;
                     break;
                 case 3:
-                    aContext.SubmitFormat = vcl::PDFWriter::XML;
+                    aContext.SubmitFormat = vcl::pdf::PDFWriter::XML;
                     break;
                 default:
                 case 0:
-                    aContext.SubmitFormat = vcl::PDFWriter::FDF;
+                    aContext.SubmitFormat = vcl::pdf::PDFWriter::FDF;
                     break;
             }
             aContext.AllowDuplicateFieldNames = bAllowDuplicateFieldNames;
@@ -986,31 +986,31 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
                 default:
                     // default: URI, without fragment conversion (the bookmark 
in PDF may not work)
                 case 0:
-                    aContext.DefaultLinkAction = vcl::PDFWriter::URIAction;
+                    aContext.DefaultLinkAction = 
vcl::pdf::PDFWriter::URIAction;
                     break;
                 case 1:
                     // view PDF through the reader application
                     aContext.ForcePDFAction = true;
-                    aContext.DefaultLinkAction = vcl::PDFWriter::LaunchAction;
+                    aContext.DefaultLinkAction = 
vcl::pdf::PDFWriter::LaunchAction;
                     break;
                 case 2:
                     // view PDF through an Internet browser
-                    aContext.DefaultLinkAction = 
vcl::PDFWriter::URIActionDestination;
+                    aContext.DefaultLinkAction = 
vcl::pdf::PDFWriter::URIActionDestination;
                     break;
                 case 3:
                     // do not emit Link annotations for external links
-                    aContext.DefaultLinkAction = 
vcl::PDFWriter::RemoveExternalLinks;
+                    aContext.DefaultLinkAction = 
vcl::pdf::PDFWriter::RemoveExternalLinks;
                     break;
                 }
                 aContext.ConvertOOoTargetToPDFTarget = 
bConvertOOoTargetToPDFTarget;
 
                 // check for Link Launch action, not allowed on PDF/A-1
                 // this code chunk checks when the filter is called from 
scripting
-                if( aContext.Version == vcl::PDFWriter::PDFVersion::PDF_A_1 &&
-                    aContext.DefaultLinkAction == vcl::PDFWriter::LaunchAction 
)
+                if( aContext.Version == 
vcl::pdf::PDFWriter::PDFVersion::PDF_A_1 &&
+                    aContext.DefaultLinkAction == 
vcl::pdf::PDFWriter::LaunchAction )
                 {
                     // force the similar allowed URI action
-                    aContext.DefaultLinkAction = 
vcl::PDFWriter::URIActionDestination;
+                    aContext.DefaultLinkAction = 
vcl::pdf::PDFWriter::URIActionDestination;
                     // and remove the remote goto action forced on PDF file
                     aContext.ForcePDFAction = false;
                 }
@@ -1026,7 +1026,7 @@ bool PDFExport::Export( const OUString& rFile, const 
Sequence< PropertyValue >&
             aContext.UseReferenceXObject = bUseReferenceXObject;
 
             // all context data set, time to create the printing device
-            vcl::PDFWriter aPDFWriter( aContext, xEnc );
+            vcl::pdf::PDFWriter aPDFWriter( aContext, xEnc );
             OutputDevice*  pOut = aPDFWriter.GetReferenceDevice();
 
             DBG_ASSERT( pOut, "PDFExport::Export: no reference device" );
@@ -1281,7 +1281,7 @@ uno::Sequence< uno::Reference< 
task::XInteractionContinuation > > SAL_CALL PDFEr
 } // end anonymous namespace
 
 
-void PDFExport::showErrors( const std::set< vcl::PDFWriter::ErrorCode >& 
rErrors )
+void PDFExport::showErrors( const std::set< vcl::pdf::PDFWriter::ErrorCode >& 
rErrors )
 {
     if( ! rErrors.empty() && mxIH.is() )
     {
@@ -1293,7 +1293,7 @@ void PDFExport::showErrors( const std::set< 
vcl::PDFWriter::ErrorCode >& rErrors
 }
 
 
-void PDFExport::ImplExportPage( vcl::PDFWriter& rWriter, 
vcl::PDFExtOutDevData& rPDFExtOutDevData, const GDIMetaFile& rMtf )
+void PDFExport::ImplExportPage( vcl::pdf::PDFWriter& rWriter, 
vcl::PDFExtOutDevData& rPDFExtOutDevData, const GDIMetaFile& rMtf )
 {
     //Rectangle(Point, Size) creates a rectangle off by 1, use Rectangle(long, 
long, long, long) instead
     basegfx::B2DPolygon aSize(tools::Polygon(tools::Rectangle(0, 0, 
rMtf.GetPrefSize().Width(), rMtf.GetPrefSize().Height())).getB2DPolygon());
@@ -1304,7 +1304,7 @@ void PDFExport::ImplExportPage( vcl::PDFWriter& rWriter, 
vcl::PDFExtOutDevData&
     rWriter.NewPage( aRangePDF.getWidth(), aRangePDF.getHeight() );
     rWriter.SetMapMode( rMtf.GetPrefMapMode() );
 
-    vcl::PDFWriter::PlayMetafileContext aCtx;
+    vcl::pdf::PDFWriter::PlayMetafileContext aCtx;
     GDIMetaFile aMtf;
     if( mbRemoveTransparencies )
     {
@@ -1345,7 +1345,7 @@ void PDFExport::ImplExportPage( vcl::PDFWriter& rWriter, 
vcl::PDFExtOutDevData&
 }
 
 
-void PDFExport::ImplWriteWatermark( vcl::PDFWriter& rWriter, const Size& 
rPageSize )
+void PDFExport::ImplWriteWatermark( vcl::pdf::PDFWriter& rWriter, const Size& 
rPageSize )
 {
     vcl::Font aFont( maWatermarkFontName, Size( 0, moWatermarkFontHeight ? 
*moWatermarkFontHeight : 3*rPageSize.Height()/4 ) );
     aFont.SetItalic( ITALIC_NONE );
@@ -1408,8 +1408,8 @@ void PDFExport::ImplWriteWatermark( vcl::PDFWriter& 
rWriter, const Size& rPageSi
     sal_Int32 const id = rWriter.EnsureStructureElement();
     rWriter.InitStructureElement(id, 
vcl::pdf::StructElement::NonStructElement, ::std::u16string_view());
     rWriter.BeginStructureElement(id);
-    rWriter.SetStructureAttribute(vcl::PDFWriter::Type, 
vcl::PDFWriter::Pagination);
-    rWriter.SetStructureAttribute(vcl::PDFWriter::Subtype, 
vcl::PDFWriter::Watermark);
+    rWriter.SetStructureAttribute(vcl::pdf::PDFWriter::Type, 
vcl::pdf::PDFWriter::Pagination);
+    rWriter.SetStructureAttribute(vcl::pdf::PDFWriter::Subtype, 
vcl::pdf::PDFWriter::Watermark);
     // HACK: this should produce *nothing* itself but is necessary to output
     // the Artifact tag here, not inside the XObject
     rWriter.DrawPolyLine({});
@@ -1459,7 +1459,7 @@ void PDFExport::ImplWriteWatermark( vcl::PDFWriter& 
rWriter, const Size& rPageSi
     rWriter.Pop();
 }
 
-void PDFExport::ImplWriteTiledWatermark( vcl::PDFWriter& rWriter, const Size& 
rPageSize )
+void PDFExport::ImplWriteTiledWatermark( vcl::pdf::PDFWriter& rWriter, const 
Size& rPageSize )
 {
     OUString watermark = msTiledWatermark;
     // Maximum number of characters in one line.
@@ -1506,8 +1506,8 @@ void PDFExport::ImplWriteTiledWatermark( vcl::PDFWriter& 
rWriter, const Size& rP
     sal_Int32 const id = rWriter.EnsureStructureElement();
     rWriter.InitStructureElement(id, 
vcl::pdf::StructElement::NonStructElement, ::std::u16string_view());
     rWriter.BeginStructureElement(id);
-    rWriter.SetStructureAttribute(vcl::PDFWriter::Type, 
vcl::PDFWriter::Pagination);
-    rWriter.SetStructureAttribute(vcl::PDFWriter::Subtype, 
vcl::PDFWriter::Watermark);
+    rWriter.SetStructureAttribute(vcl::pdf::PDFWriter::Type, 
vcl::pdf::PDFWriter::Pagination);
+    rWriter.SetStructureAttribute(vcl::pdf::PDFWriter::Subtype, 
vcl::pdf::PDFWriter::Watermark);
     // HACK: this should produce *nothing* itself but is necessary to output
     // the Artifact tag here, not inside the XObject
     rWriter.DrawPolyLine({});
diff --git a/filter/source/pdf/pdfexport.hxx b/filter/source/pdf/pdfexport.hxx
index f4e3e20fbb17..8e6a8cd6b613 100644
--- a/filter/source/pdf/pdfexport.hxx
+++ b/filter/source/pdf/pdfexport.hxx
@@ -59,11 +59,11 @@ private:
     std::optional<Degree10> moWatermarkRotateAngle;
     OUString            msTiledWatermark;
 
-    void                ImplExportPage( vcl::PDFWriter& rWriter, 
vcl::PDFExtOutDevData& rPDFExtOutDevData,
+    void                ImplExportPage( vcl::pdf::PDFWriter& rWriter, 
vcl::PDFExtOutDevData& rPDFExtOutDevData,
                                         const GDIMetaFile& rMtf );
 
-    void                ImplWriteWatermark( vcl::PDFWriter& rWriter, const 
Size& rPageSize );
-    void                ImplWriteTiledWatermark( vcl::PDFWriter& rWriter, 
const Size& rPageSize );
+    void                ImplWriteWatermark( vcl::pdf::PDFWriter& rWriter, 
const Size& rPageSize );
+    void                ImplWriteTiledWatermark( vcl::pdf::PDFWriter& rWriter, 
const Size& rPageSize );
     css::uno::Reference<css::security::XCertificate> 
GetCertificateFromSubjectName(std::u16string_view rSubjectName) const;
 
 
@@ -75,7 +75,7 @@ public:
                                     const css::uno::Reference< 
css::uno::XComponentContext >& xFact );
                         ~PDFExport();
 
-    bool                ExportSelection( vcl::PDFWriter& rPDFWriter,
+    bool                ExportSelection( vcl::pdf::PDFWriter& rPDFWriter,
                                     css::uno::Reference< 
css::view::XRenderable > const & rRenderable,
                                     const css::uno::Any& rSelection,
                                     const StringRangeEnumerator& rRangeEnum,
@@ -84,7 +84,7 @@ public:
 
     bool                Export( const OUString& rFile, const 
css::uno::Sequence< css::beans::PropertyValue >& rFilterData );
 
-    void                showErrors( const std::set<vcl::PDFWriter::ErrorCode>& 
);
+    void                showErrors( const 
std::set<vcl::pdf::PDFWriter::ErrorCode>& );
 };
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/filter/source/pdf/pdfinteract.cxx 
b/filter/source/pdf/pdfinteract.cxx
index bd08fd0b292b..26eaaa40da6b 100644
--- a/filter/source/pdf/pdfinteract.cxx
+++ b/filter/source/pdf/pdfinteract.cxx
@@ -55,10 +55,10 @@ sal_Bool SAL_CALL 
PDFInteractionHandler::handleInteractionRequest( const Referen
     task::PDFExportException aExc;
     if( aRequest >>= aExc )
     {
-        std::set< vcl::PDFWriter::ErrorCode > aCodes;
+        std::set< vcl::pdf::PDFWriter::ErrorCode > aCodes;
         sal_Int32 nCodes = aExc.ErrorCodes.getLength();
         for( sal_Int32 i = 0; i < nCodes; i++ )
-            aCodes.insert( 
static_cast<vcl::PDFWriter::ErrorCode>(aExc.ErrorCodes.getConstArray()[i]) );
+            aCodes.insert( 
static_cast<vcl::pdf::PDFWriter::ErrorCode>(aExc.ErrorCodes.getConstArray()[i]) 
);
 
         ImplErrorDialog aDlg(Application::GetFrameWeld(m_xParent), aCodes);
         aDlg.run();
diff --git a/include/vcl/formpdfexport.hxx b/include/vcl/formpdfexport.hxx
index a2aed55efe8d..cce646376eca 100644
--- a/include/vcl/formpdfexport.hxx
+++ b/include/vcl/formpdfexport.hxx
@@ -41,7 +41,7 @@ namespace toolkitform
 
     /** creates a PDF compatible control descriptor for the given control
     */
-    std::unique_ptr<vcl::PDFWriter::AnyWidget> VCL_DLLPUBLIC 
describePDFControl(
+    std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> VCL_DLLPUBLIC 
describePDFControl(
             const css::uno::Reference< css::awt::XControl >& _rxControl,
             vcl::PDFExtOutDevData& i_pdfExportData
         );
diff --git a/include/vcl/pdfextoutdevdata.hxx b/include/vcl/pdfextoutdevdata.hxx
index 6ea175c905eb..50e1c554ce8a 100644
--- a/include/vcl/pdfextoutdevdata.hxx
+++ b/include/vcl/pdfextoutdevdata.hxx
@@ -106,10 +106,10 @@ public:
     PDFExtOutDevData( const OutputDevice& rOutDev );
     virtual ~PDFExtOutDevData() override;
 
-    bool PlaySyncPageAct( PDFWriter& rWriter, sal_uInt32& rCurGDIMtfAction, 
const GDIMetaFile& rMtf );
-    void ResetSyncData(PDFWriter * pWriterIfRemoveTransparencies);
+    bool PlaySyncPageAct( pdf::PDFWriter& rWriter, sal_uInt32& 
rCurGDIMtfAction, const GDIMetaFile& rMtf );
+    void ResetSyncData(pdf::PDFWriter * pWriterIfRemoveTransparencies);
 
-    void PlayGlobalActions( PDFWriter& rWriter );
+    void PlayGlobalActions( pdf::PDFWriter& rWriter );
 
     bool    GetIsExportNotes() const { return mbExportNotes;}
     void        SetIsExportNotes( const bool bExportNotes );
@@ -240,7 +240,7 @@ public:
 
     /** provides detailed information about a destination range which 
previously has been registered using RegisterDest.
     */
-    void        DescribeRegisteredDest( sal_Int32 nDestId, const 
tools::Rectangle& rRect, sal_Int32 nPageNr, PDFWriter::DestAreaType eType = 
PDFWriter::DestAreaType::XYZ );
+    void        DescribeRegisteredDest( sal_Int32 nDestId, const 
tools::Rectangle& rRect, sal_Int32 nPageNr, pdf::PDFWriter::DestAreaType eType 
= pdf::PDFWriter::DestAreaType::XYZ );
 
 //<---i56629
 
@@ -260,7 +260,7 @@ public:
     the destination id (to be used in SetLinkDest) or
     -1 if page id does not exist
     */
-    sal_Int32 CreateDest( const tools::Rectangle& rRect, sal_Int32 nPageNr = 
-1, PDFWriter::DestAreaType eType = PDFWriter::DestAreaType::XYZ );
+    sal_Int32 CreateDest( const tools::Rectangle& rRect, sal_Int32 nPageNr = 
-1, pdf::PDFWriter::DestAreaType eType = pdf::PDFWriter::DestAreaType::XYZ );
     /** Create a new link on a page
 
     @param rRect
@@ -436,7 +436,7 @@ public:
     @param eVal
     the value to set the attribute to
      */
-    void SetStructureAttribute( PDFWriter::StructAttribute eAttr, 
PDFWriter::StructAttributeValue eVal );
+    void SetStructureAttribute( pdf::PDFWriter::StructAttribute eAttr, 
pdf::PDFWriter::StructAttributeValue eVal );
     /** set a structure attribute on the current structural element
 
     SetStructureAttributeNumerical sets an attribute of the current structural 
element
@@ -450,7 +450,7 @@ public:
     @param nValue
     the value to set the attribute to
      */
-    void SetStructureAttributeNumerical( PDFWriter::StructAttribute eAttr, 
sal_Int32 nValue );
+    void SetStructureAttributeNumerical( pdf::PDFWriter::StructAttribute 
eAttr, sal_Int32 nValue );
     /** set the bounding box of a structural element
 
     SetStructureBoundingBox sets the BBox attribute to a new value. Since the 
BBox
@@ -501,7 +501,7 @@ public:
     the duration of the transitional effect in milliseconds;
     set 0 to disable transitional effects
     */
-    void SetPageTransition( PDFWriter::PageTransition eType, sal_uInt32 
nMilliSec );
+    void SetPageTransition( pdf::PDFWriter::PageTransition eType, sal_uInt32 
nMilliSec );
 
     /** create a new form control
 
@@ -512,7 +512,7 @@ public:
     @param rControlType
     a descendant of AnyWidget determining the control's properties
      */
-    void    CreateControl( const PDFWriter::AnyWidget& rControlType );
+    void    CreateControl( const pdf::PDFWriter::AnyWidget& rControlType );
 };
 
 }
diff --git a/include/vcl/pdfwriter.hxx b/include/vcl/pdfwriter.hxx
index 13480459085e..84c47705c25a 100644
--- a/include/vcl/pdfwriter.hxx
+++ b/include/vcl/pdfwriter.hxx
@@ -181,8 +181,6 @@ enum class StructElement
     Figure, Formula, Form
 };
 
-}
-
 class PDFWriter
 {
     ScopedVclPtr<PDFWriterImpl> xImplementation;
@@ -441,7 +439,7 @@ public:
         bool                SubmitGet;
 
         PushButtonWidget()
-                : AnyWidget( vcl::PDFWriter::PushButton ),
+                : AnyWidget( PDFWriter::PushButton ),
                   Dest( -1 ), Submit( false ), SubmitGet( false )
         {}
 
@@ -458,7 +456,7 @@ public:
         OUString            OffValue; // the value of the checkbox if it is 
not selected
 
         CheckBoxWidget()
-                : AnyWidget( vcl::PDFWriter::CheckBox ),
+                : AnyWidget( PDFWriter::CheckBox ),
                   Checked( false )
         {}
 
@@ -476,7 +474,7 @@ public:
         OUString       OffValue; // the value of the radio button if it is not 
selected
 
         RadioButtonWidget()
-                : AnyWidget( vcl::PDFWriter::RadioButton ),
+                : AnyWidget( PDFWriter::RadioButton ),
                   Selected( false ),
                   RadioGroup( 0 )
         {}
@@ -509,7 +507,7 @@ public:
         OUString            DateFormat;
 
         EditWidget()
-                : AnyWidget( vcl::PDFWriter::Edit ),
+                : AnyWidget( PDFWriter::Edit ),
                   MultiLine( false ),
                   Password( false ),
                   FileSelect( false ),
@@ -536,7 +534,7 @@ public:
          // since multiselect is a 1.4+ feature
 
         ListBoxWidget()
-                : AnyWidget( vcl::PDFWriter::ListBox ),
+                : AnyWidget( PDFWriter::ListBox ),
                   DropDown( false ),
                   MultiSelect( false )
         {}
@@ -554,7 +552,7 @@ public:
         // set the current value in AnyWidget::Text
 
         ComboBoxWidget()
-                : AnyWidget( vcl::PDFWriter::ComboBox )
+                : AnyWidget( PDFWriter::ComboBox )
         {}
 
         virtual std::shared_ptr<AnyWidget> Clone() const override
@@ -566,7 +564,7 @@ public:
     struct SignatureWidget final : public AnyWidget
     {
         SignatureWidget()
-                : AnyWidget( vcl::PDFWriter::Signature )
+                : AnyWidget( PDFWriter::Signature )
         {}
 
         virtual std::shared_ptr<AnyWidget> Clone() const override
@@ -1304,7 +1302,9 @@ public:
     static OString GetDateTime(svl::crypto::SigningContext* pSigningContext = 
nullptr);
 };
 
-}
+} // end namespace vcl::pdf
+
+} // end namespace vcl
 
 #endif // INCLUDED_VCL_PDFWRITER_HXX
 
diff --git a/sd/source/ui/unoidl/unomodel.cxx b/sd/source/ui/unoidl/unomodel.cxx
index 970942f22bee..b51403690386 100644
--- a/sd/source/ui/unoidl/unomodel.cxx
+++ b/sd/source/ui/unoidl/unomodel.cxx
@@ -3311,14 +3311,14 @@ static void ImplPDFExportShapeInteraction( const 
uno::Reference< drawing::XShape
                     case presentation::ClickAction_LASTPAGE :
                     {
                         sal_Int32 nCount = rDoc.GetSdPageCount( 
PageKind::Standard );
-                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nCount - 1, vcl::PDFWriter::DestAreaType::FitRectangle );
+                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nCount - 1, vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                         sal_Int32 nLinkId = 
rPDFExtOutDevData.CreateLink(aLinkRect, actionName);
                         rPDFExtOutDevData.SetLinkDest( nLinkId, nDestId );
                     }
                     break;
                     case presentation::ClickAction_FIRSTPAGE :
                     {
-                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, 0, vcl::PDFWriter::DestAreaType::FitRectangle );
+                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, 0, vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                         sal_Int32 nLinkId = 
rPDFExtOutDevData.CreateLink(aLinkRect, actionName);
                         rPDFExtOutDevData.SetLinkDest( nLinkId, nDestId );
                     }
@@ -3328,7 +3328,7 @@ static void ImplPDFExportShapeInteraction( const 
uno::Reference< drawing::XShape
                         sal_Int32 nDestPage = 
rPDFExtOutDevData.GetCurrentPageNumber();
                         if ( nDestPage )
                             nDestPage--;
-                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nDestPage, vcl::PDFWriter::DestAreaType::FitRectangle );
+                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nDestPage, vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                         sal_Int32 nLinkId = 
rPDFExtOutDevData.CreateLink(aLinkRect, actionName);
                         rPDFExtOutDevData.SetLinkDest( nLinkId, nDestId );
                     }
@@ -3339,7 +3339,7 @@ static void ImplPDFExportShapeInteraction( const 
uno::Reference< drawing::XShape
                         sal_Int32 nLastPage = rDoc.GetSdPageCount( 
PageKind::Standard ) - 1;
                         if ( nDestPage > nLastPage )
                             nDestPage = nLastPage;
-                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nDestPage, vcl::PDFWriter::DestAreaType::FitRectangle );
+                        sal_Int32 nDestId = rPDFExtOutDevData.CreateDest( 
aPageRect, nDestPage, vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                         sal_Int32 nLinkId = 
rPDFExtOutDevData.CreateLink(aLinkRect, actionName);
                         rPDFExtOutDevData.SetLinkDest( nLinkId, nDestId );
                     }
@@ -3367,7 +3367,7 @@ static void ImplPDFExportShapeInteraction( const 
uno::Reference< drawing::XShape
                                     sal_Int32 nPage = ImplPDFGetBookmarkPage( 
aBookmark, rDoc );
                                     if ( nPage != -1 )
                                     {
-                                        sal_Int32 nDestId = 
rPDFExtOutDevData.CreateDest( aPageRect, nPage, 
vcl::PDFWriter::DestAreaType::FitRectangle );
+                                        sal_Int32 nDestId = 
rPDFExtOutDevData.CreateDest( aPageRect, nPage, 
vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                                         sal_Int32 nLinkId = 
rPDFExtOutDevData.CreateLink(aLinkRect, actionName);
                                         rPDFExtOutDevData.SetLinkDest( 
nLinkId, nDestId );
                                     }
@@ -3648,7 +3648,7 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                 }
                             }
                             presentation::FadeEffect eFe;
-                            vcl::PDFWriter::PageTransition eType = 
vcl::PDFWriter::PageTransition::Regular;
+                            vcl::pdf::PDFWriter::PageTransition eType = 
vcl::pdf::PDFWriter::PageTransition::Regular;
                             if ( xPagePropSet->getPropertySetInfo( 
)->hasPropertyByName( sEffect ) )
                             {
                                 aAny = xPagePropSet->getPropertyValue( sEffect 
);
@@ -3658,11 +3658,11 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                     {
                                         case 
presentation::FadeEffect_HORIZONTAL_LINES :
                                         case 
presentation::FadeEffect_HORIZONTAL_CHECKERBOARD :
-                                        case 
presentation::FadeEffect_HORIZONTAL_STRIPES : eType = 
vcl::PDFWriter::PageTransition::BlindsHorizontal; break;
+                                        case 
presentation::FadeEffect_HORIZONTAL_STRIPES : eType = 
vcl::pdf::PDFWriter::PageTransition::BlindsHorizontal; break;
 
                                         case 
presentation::FadeEffect_VERTICAL_LINES :
                                         case 
presentation::FadeEffect_VERTICAL_CHECKERBOARD :
-                                        case 
presentation::FadeEffect_VERTICAL_STRIPES : eType = 
vcl::PDFWriter::PageTransition::BlindsVertical; break;
+                                        case 
presentation::FadeEffect_VERTICAL_STRIPES : eType = 
vcl::pdf::PDFWriter::PageTransition::BlindsVertical; break;
 
                                         case 
presentation::FadeEffect_UNCOVER_TO_RIGHT :
                                         case 
presentation::FadeEffect_UNCOVER_TO_UPPERRIGHT :
@@ -3670,7 +3670,7 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                         case 
presentation::FadeEffect_FADE_FROM_UPPERLEFT :
                                         case 
presentation::FadeEffect_MOVE_FROM_UPPERLEFT :
                                         case 
presentation::FadeEffect_FADE_FROM_LEFT :
-                                        case 
presentation::FadeEffect_MOVE_FROM_LEFT : eType = 
vcl::PDFWriter::PageTransition::WipeLeftToRight; break;
+                                        case 
presentation::FadeEffect_MOVE_FROM_LEFT : eType = 
vcl::pdf::PDFWriter::PageTransition::WipeLeftToRight; break;
 
                                         case 
presentation::FadeEffect_UNCOVER_TO_BOTTOM :
                                         case 
presentation::FadeEffect_UNCOVER_TO_LOWERRIGHT :
@@ -3678,7 +3678,7 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                         case 
presentation::FadeEffect_FADE_FROM_UPPERRIGHT :
                                         case 
presentation::FadeEffect_MOVE_FROM_UPPERRIGHT :
                                         case 
presentation::FadeEffect_FADE_FROM_TOP :
-                                        case 
presentation::FadeEffect_MOVE_FROM_TOP : eType = 
vcl::PDFWriter::PageTransition::WipeTopToBottom; break;
+                                        case 
presentation::FadeEffect_MOVE_FROM_TOP : eType = 
vcl::pdf::PDFWriter::PageTransition::WipeTopToBottom; break;
 
                                         case 
presentation::FadeEffect_UNCOVER_TO_LEFT :
                                         case 
presentation::FadeEffect_UNCOVER_TO_LOWERLEFT :
@@ -3687,7 +3687,7 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                         case 
presentation::FadeEffect_FADE_FROM_LOWERRIGHT :
                                         case 
presentation::FadeEffect_MOVE_FROM_LOWERRIGHT :
                                         case 
presentation::FadeEffect_FADE_FROM_RIGHT :
-                                        case 
presentation::FadeEffect_MOVE_FROM_RIGHT : eType = 
vcl::PDFWriter::PageTransition::WipeRightToLeft; break;
+                                        case 
presentation::FadeEffect_MOVE_FROM_RIGHT : eType = 
vcl::pdf::PDFWriter::PageTransition::WipeRightToLeft; break;
 
                                         case 
presentation::FadeEffect_UNCOVER_TO_TOP :
                                         case 
presentation::FadeEffect_UNCOVER_TO_UPPERLEFT :
@@ -3695,22 +3695,22 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                                         case 
presentation::FadeEffect_FADE_FROM_LOWERLEFT :
                                         case 
presentation::FadeEffect_MOVE_FROM_LOWERLEFT :
                                         case 
presentation::FadeEffect_FADE_FROM_BOTTOM :
-                                        case 
presentation::FadeEffect_MOVE_FROM_BOTTOM : eType = 
vcl::PDFWriter::PageTransition::WipeBottomToTop; break;
+                                        case 
presentation::FadeEffect_MOVE_FROM_BOTTOM : eType = 
vcl::pdf::PDFWriter::PageTransition::WipeBottomToTop; break;
 
-                                        case 
presentation::FadeEffect_OPEN_VERTICAL : eType = 
vcl::PDFWriter::PageTransition::SplitHorizontalInward; break;
-                                        case 
presentation::FadeEffect_CLOSE_HORIZONTAL : eType = 
vcl::PDFWriter::PageTransition::SplitHorizontalOutward; break;
+                                        case 
presentation::FadeEffect_OPEN_VERTICAL : eType = 
vcl::pdf::PDFWriter::PageTransition::SplitHorizontalInward; break;
+                                        case 
presentation::FadeEffect_CLOSE_HORIZONTAL : eType = 
vcl::pdf::PDFWriter::PageTransition::SplitHorizontalOutward; break;
 
-                                        case 
presentation::FadeEffect_OPEN_HORIZONTAL : eType = 
vcl::PDFWriter::PageTransition::SplitVerticalInward; break;
-                                        case 
presentation::FadeEffect_CLOSE_VERTICAL : eType = 
vcl::PDFWriter::PageTransition::SplitVerticalOutward; break;
+                                        case 
presentation::FadeEffect_OPEN_HORIZONTAL : eType = 
vcl::pdf::PDFWriter::PageTransition::SplitVerticalInward; break;
+                                        case 
presentation::FadeEffect_CLOSE_VERTICAL : eType = 
vcl::pdf::PDFWriter::PageTransition::SplitVerticalOutward; break;
 
-                                        case 
presentation::FadeEffect_FADE_TO_CENTER : eType = 
vcl::PDFWriter::PageTransition::BoxInward; break;
-                                        case 
presentation::FadeEffect_FADE_FROM_CENTER : eType = 
vcl::PDFWriter::PageTransition::BoxOutward; break;
+                                        case 
presentation::FadeEffect_FADE_TO_CENTER : eType = 
vcl::pdf::PDFWriter::PageTransition::BoxInward; break;
+                                        case 
presentation::FadeEffect_FADE_FROM_CENTER : eType = 
vcl::pdf::PDFWriter::PageTransition::BoxOutward; break;
 
-                                        case presentation::FadeEffect_NONE : 
eType = vcl::PDFWriter::PageTransition::Regular; break;
+                                        case presentation::FadeEffect_NONE : 
eType = vcl::pdf::PDFWriter::PageTransition::Regular; break;
 
                                         case presentation::FadeEffect_RANDOM :
                                         case presentation::FadeEffect_DISSOLVE 
:
-                                        default: eType = 
vcl::PDFWriter::PageTransition::Dissolve; break;
+                                        default: eType = 
vcl::pdf::PDFWriter::PageTransition::Dissolve; break;
                                     }
                                 }
                             }
@@ -3747,9 +3747,9 @@ void SAL_CALL SdXImpressDocument::render( sal_Int32 
nRenderer, const uno::Any& r
                     if ( nPage != -1 )
                     {
                         if ( rBookmark.nLinkId != -1 )
-                            pPDFExtOutDevData->SetLinkDest( rBookmark.nLinkId, 
pPDFExtOutDevData->CreateDest( aPageRect, nPage, 
vcl::PDFWriter::DestAreaType::FitRectangle ) );
+                            pPDFExtOutDevData->SetLinkDest( rBookmark.nLinkId, 
pPDFExtOutDevData->CreateDest( aPageRect, nPage, 
vcl::pdf::PDFWriter::DestAreaType::FitRectangle ) );
                         else
-                            pPDFExtOutDevData->DescribeRegisteredDest( 
rBookmark.nDestId, aPageRect, nPage, vcl::PDFWriter::DestAreaType::FitRectangle 
);
+                            pPDFExtOutDevData->DescribeRegisteredDest( 
rBookmark.nDestId, aPageRect, nPage, 
vcl::pdf::PDFWriter::DestAreaType::FitRectangle );
                     }
                     else
                         pPDFExtOutDevData->SetLinkURL( rBookmark.nLinkId, 
rBookmark.aBookmark );
diff --git a/sw/source/core/text/itrform2.cxx b/sw/source/core/text/itrform2.cxx
index 2424ddbcc992..a5363e06544a 100644
--- a/sw/source/core/text/itrform2.cxx
+++ b/sw/source/core/text/itrform2.cxx
@@ -1040,21 +1040,21 @@ bool SwContentControlPortion::DescribePDFControl(const 
SwTextPaintInfo& rInf) co
     };
     const OUString aText = comphelper::string::removeAny(aPam.GetText(), 
aForbidden);
 
-    std::unique_ptr<vcl::PDFWriter::AnyWidget> pDescriptor;
+    std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> pDescriptor;
     switch (pContentControl->GetType())
     {
         case SwContentControlType::RICH_TEXT:
         case SwContentControlType::PLAIN_TEXT:
         {
-            pDescriptor = std::make_unique<vcl::PDFWriter::EditWidget>();
-            auto pEditWidget = 
static_cast<vcl::PDFWriter::EditWidget*>(pDescriptor.get());
+            pDescriptor = std::make_unique<vcl::pdf::PDFWriter::EditWidget>();
+            auto pEditWidget = 
static_cast<vcl::pdf::PDFWriter::EditWidget*>(pDescriptor.get());
             pEditWidget->MultiLine = true;
             break;
         }
         case SwContentControlType::CHECKBOX:
         {
-            pDescriptor = std::make_unique<vcl::PDFWriter::CheckBoxWidget>();
-            auto pCheckBoxWidget = 
static_cast<vcl::PDFWriter::CheckBoxWidget*>(pDescriptor.get());
+            pDescriptor = 
std::make_unique<vcl::pdf::PDFWriter::CheckBoxWidget>();
+            auto pCheckBoxWidget = 
static_cast<vcl::pdf::PDFWriter::CheckBoxWidget*>(pDescriptor.get());
             pCheckBoxWidget->Checked = pContentControl->GetChecked();
             // If it's checked already, then leave the default "Yes" OnValue 
unchanged, so the
             // appropriate appearance is found by PDF readers.
@@ -1067,8 +1067,8 @@ bool SwContentControlPortion::DescribePDFControl(const 
SwTextPaintInfo& rInf) co
         }
         case SwContentControlType::DROP_DOWN_LIST:
         {
-            pDescriptor = std::make_unique<vcl::PDFWriter::ListBoxWidget>();
-            auto pListWidget = 
static_cast<vcl::PDFWriter::ListBoxWidget*>(pDescriptor.get());
+            pDescriptor = 
std::make_unique<vcl::pdf::PDFWriter::ListBoxWidget>();
+            auto pListWidget = 
static_cast<vcl::pdf::PDFWriter::ListBoxWidget*>(pDescriptor.get());
             pListWidget->DropDown = true;
             sal_Int32 nIndex = 0;
             bool bTextFound = false;
@@ -1093,8 +1093,8 @@ bool SwContentControlPortion::DescribePDFControl(const 
SwTextPaintInfo& rInf) co
         }
         case SwContentControlType::COMBO_BOX:
         {
-            pDescriptor = std::make_unique<vcl::PDFWriter::ComboBoxWidget>();
-            auto pComboWidget = 
static_cast<vcl::PDFWriter::ComboBoxWidget*>(pDescriptor.get());
+            pDescriptor = 
std::make_unique<vcl::pdf::PDFWriter::ComboBoxWidget>();
+            auto pComboWidget = 
static_cast<vcl::pdf::PDFWriter::ComboBoxWidget*>(pDescriptor.get());
             for (const auto& rItem : pContentControl->GetListItems())
             {
                 pComboWidget->Entries.push_back(rItem.m_aDisplayText);
@@ -1103,9 +1103,9 @@ bool SwContentControlPortion::DescribePDFControl(const 
SwTextPaintInfo& rInf) co
         }
         case SwContentControlType::DATE:
         {
-            pDescriptor = std::make_unique<vcl::PDFWriter::EditWidget>();
-            auto pEditWidget = 
static_cast<vcl::PDFWriter::EditWidget*>(pDescriptor.get());
-            pEditWidget->Format = vcl::PDFWriter::Date;
+            pDescriptor = std::make_unique<vcl::pdf::PDFWriter::EditWidget>();
+            auto pEditWidget = 
static_cast<vcl::pdf::PDFWriter::EditWidget*>(pDescriptor.get());
+            pEditWidget->Format = vcl::pdf::PDFWriter::Date;
             // GetDateFormat() uses a syntax that works with 
SvNumberFormatter::PutEntry(), PDF's
             // AFDate_FormatEx() uses a similar syntax, but uses lowercase 
characters in case of
             // "Y", "M" and "D" at least.
diff --git a/sw/source/core/text/porfld.cxx b/sw/source/core/text/porfld.cxx
index 286e23a85186..6d4c65babfd6 100644
--- a/sw/source/core/text/porfld.cxx
+++ b/sw/source/core/text/porfld.cxx
@@ -1444,7 +1444,7 @@ bool SwJumpFieldPortion::DescribePDFControl(const 
SwTextPaintInfo& rInf) const
     if (m_nFormat != SwJumpEditFormat::Text)
         return false;
 
-    vcl::PDFWriter::EditWidget aDescriptor;
+    vcl::pdf::PDFWriter::EditWidget aDescriptor;
 
     aDescriptor.Border = true;
     aDescriptor.BorderColor = COL_BLACK;
diff --git a/vcl/source/filter/ipdf/pdfdocument.cxx 
b/vcl/source/filter/ipdf/pdfdocument.cxx
index 4595047a347b..8a344e3dcf5d 100644
--- a/vcl/source/filter/ipdf/pdfdocument.cxx
+++ b/vcl/source/filter/ipdf/pdfdocument.cxx
@@ -147,7 +147,7 @@ sal_Int32 
PDFDocument::WriteSignatureObject(svl::crypto::SigningContext& rSignin
         aSigBuffer.append("/adbe.pkcs7.detached");
 
     // Time of signing.
-    aSigBuffer.append(" /M (" + vcl::PDFWriter::GetDateTime(&rSigningContext)
+    aSigBuffer.append(" /M (" + 
vcl::pdf::PDFWriter::GetDateTime(&rSigningContext)
                       + ")"
 
                         // Byte range: we can write offset1-length1 and 
offset2 right now, will
diff --git a/vcl/source/gdi/formpdfexport.cxx b/vcl/source/gdi/formpdfexport.cxx
index 7a2f253e5dc1..175f57eca58e 100644
--- a/vcl/source/gdi/formpdfexport.cxx
+++ b/vcl/source/gdi/formpdfexport.cxx
@@ -120,20 +120,20 @@ namespace toolkitform
 
         /** (default-)creates a PDF widget according to a given 
FormComponentType
         */
-        std::unique_ptr<vcl::PDFWriter::AnyWidget> createDefaultWidget( 
sal_Int16 _nFormComponentType )
+        std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> createDefaultWidget( 
sal_Int16 _nFormComponentType )
         {
             switch ( _nFormComponentType )
             {
             case FormComponentType::COMMANDBUTTON:
-                return std::make_unique<vcl::PDFWriter::PushButtonWidget>();
+                return 
std::make_unique<vcl::pdf::PDFWriter::PushButtonWidget>();
             case FormComponentType::CHECKBOX:
-                return std::make_unique<vcl::PDFWriter::CheckBoxWidget>();
+                return std::make_unique<vcl::pdf::PDFWriter::CheckBoxWidget>();
             case FormComponentType::RADIOBUTTON:
-                return std::make_unique<vcl::PDFWriter::RadioButtonWidget>();
+                return 
std::make_unique<vcl::pdf::PDFWriter::RadioButtonWidget>();
             case FormComponentType::LISTBOX:
-                return std::make_unique<vcl::PDFWriter::ListBoxWidget>();
+                return std::make_unique<vcl::pdf::PDFWriter::ListBoxWidget>();
             case FormComponentType::COMBOBOX:
-                return std::make_unique<vcl::PDFWriter::ComboBoxWidget>();
+                return std::make_unique<vcl::pdf::PDFWriter::ComboBoxWidget>();
 
             case FormComponentType::TEXTFIELD:
             case FormComponentType::FILECONTROL:
@@ -142,7 +142,7 @@ namespace toolkitform
             case FormComponentType::NUMERICFIELD:
             case FormComponentType::CURRENCYFIELD:
             case FormComponentType::PATTERNFIELD:
-                return std::make_unique<vcl::PDFWriter::EditWidget>();
+                return std::make_unique<vcl::pdf::PDFWriter::EditWidget>();
             }
             return nullptr;
         }
@@ -311,10 +311,10 @@ namespace toolkitform
 
     /** creates a PDF compatible control descriptor for the given control
     */
-    std::unique_ptr<vcl::PDFWriter::AnyWidget> describePDFControl( const 
Reference< XControl >& _rxControl,
+    std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> describePDFControl( const 
Reference< XControl >& _rxControl,
         vcl::PDFExtOutDevData& i_pdfExportData )
     {
-        std::unique_ptr<vcl::PDFWriter::AnyWidget> Descriptor;
+        std::unique_ptr<vcl::pdf::PDFWriter::AnyWidget> Descriptor;
         OSL_ENSURE( _rxControl.is(), "describePDFControl: invalid (NULL) 
control!" );
         if ( !_rxControl.is() )
             return Descriptor;
@@ -494,9 +494,9 @@ namespace toolkitform
             // special widget properties
 
             // edits
-            if ( Descriptor->getType() == vcl::PDFWriter::Edit )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::Edit )
             {
-                vcl::PDFWriter::EditWidget* pEditWidget = static_cast< 
vcl::PDFWriter::EditWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::EditWidget* pEditWidget = static_cast< 
vcl::pdf::PDFWriter::EditWidget* >( Descriptor.get() );
 
                 // multiline (already flagged in the TextStyle)
                 pEditWidget->MultiLine = bool( Descriptor->TextStyle & 
DrawTextFlags::MultiLine );
@@ -533,7 +533,7 @@ namespace toolkitform
                     case FormComponentType::NUMERICFIELD:
                     {
 
-                        pEditWidget->Format = vcl::PDFWriter::Number;
+                        pEditWidget->Format = vcl::pdf::PDFWriter::Number;
 
                         static constexpr OUString FM_PROP_CURRENCYSYMBOL = 
u"CurrencySymbol"_ustr;
                         if ( xPSI->hasPropertyByName( FM_PROP_CURRENCYSYMBOL ) 
)
@@ -564,7 +564,7 @@ namespace toolkitform
                     } break;
                     case FormComponentType::TIMEFIELD:
                     {
-                        pEditWidget->Format = vcl::PDFWriter::Time;
+                        pEditWidget->Format = vcl::pdf::PDFWriter::Time;
 
                         static constexpr OUString FM_PROP_TIMEFORMAT = 
u"TimeFormat"_ustr;
                         if ( xPSI->hasPropertyByName( FM_PROP_TIMEFORMAT ) )
@@ -592,7 +592,7 @@ namespace toolkitform
                     } break;
                     case FormComponentType::DATEFIELD:
                     {
-                        pEditWidget->Format = vcl::PDFWriter::Date;
+                        pEditWidget->Format = vcl::pdf::PDFWriter::Date;
 
                         static constexpr OUString FM_PROP_DATEFORMAT = 
u"DateFormat"_ustr;
                         if ( xPSI->hasPropertyByName( FM_PROP_DATEFORMAT ) )
@@ -642,9 +642,9 @@ namespace toolkitform
             }
 
             // buttons
-            if ( Descriptor->getType() == vcl::PDFWriter::PushButton )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::PushButton )
             {
-                vcl::PDFWriter::PushButtonWidget* pButtonWidget = static_cast< 
vcl::PDFWriter::PushButtonWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::PushButtonWidget* pButtonWidget = 
static_cast< vcl::pdf::PDFWriter::PushButtonWidget* >( Descriptor.get() );
                 FormButtonType eButtonType = FormButtonType_PUSH;
                 if( ! (xModelProps->getPropertyValue(u"ButtonType"_ustr) >>= 
eButtonType) )
                     SAL_WARN("toolkit.helper", "describePDFControl: unable to 
get property ButtonType");
@@ -711,9 +711,9 @@ namespace toolkitform
 
             // check boxes
             static constexpr OUString FM_PROP_STATE = u"State"_ustr;
-            if ( Descriptor->getType() == vcl::PDFWriter::CheckBox )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::CheckBox )
             {
-                vcl::PDFWriter::CheckBoxWidget* pCheckBoxWidget = static_cast< 
vcl::PDFWriter::CheckBoxWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::CheckBoxWidget* pCheckBoxWidget = 
static_cast< vcl::pdf::PDFWriter::CheckBoxWidget* >( Descriptor.get() );
                 sal_Int16 nState = 0;
                 if( ! (xModelProps->getPropertyValue( FM_PROP_STATE ) >>= 
nState) )
                     SAL_WARN("toolkit.helper", "describePDFControl: unable to 
get property " << FM_PROP_STATE);
@@ -738,9 +738,9 @@ namespace toolkitform
 
 
             // radio buttons
-            if ( Descriptor->getType() == vcl::PDFWriter::RadioButton )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::RadioButton )
             {
-                vcl::PDFWriter::RadioButtonWidget* pRadioWidget = static_cast< 
vcl::PDFWriter::RadioButtonWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::RadioButtonWidget* pRadioWidget = 
static_cast< vcl::pdf::PDFWriter::RadioButtonWidget* >( Descriptor.get() );
                 sal_Int16 nState = 0;
                 if( ! (xModelProps->getPropertyValue( FM_PROP_STATE ) >>= 
nState) )
                     SAL_WARN("toolkit.helper", "describePDFControl: unable to 
get property " << FM_PROP_STATE);
@@ -765,9 +765,9 @@ namespace toolkitform
 
 
             // list boxes
-            if ( Descriptor->getType() == vcl::PDFWriter::ListBox )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::ListBox )
             {
-                vcl::PDFWriter::ListBoxWidget* pListWidget = static_cast< 
vcl::PDFWriter::ListBoxWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::ListBoxWidget* pListWidget = static_cast< 
vcl::pdf::PDFWriter::ListBoxWidget* >( Descriptor.get() );
 
                 // drop down
                 if( ! (xModelProps->getPropertyValue( u"Dropdown"_ustr ) >>= 
pListWidget->DropDown) )
@@ -795,9 +795,9 @@ namespace toolkitform
 
 
             // combo boxes
-            if ( Descriptor->getType() == vcl::PDFWriter::ComboBox )
+            if ( Descriptor->getType() == vcl::pdf::PDFWriter::ComboBox )
             {
-                vcl::PDFWriter::ComboBoxWidget* pComboWidget = static_cast< 
vcl::PDFWriter::ComboBoxWidget* >( Descriptor.get() );
+                vcl::pdf::PDFWriter::ComboBoxWidget* pComboWidget = 
static_cast< vcl::pdf::PDFWriter::ComboBoxWidget* >( Descriptor.get() );
 
                 // entries
                 getStringItemVector( xModelProps, pComboWidget->Entries );
diff --git a/vcl/source/pdf/pdfextoutdevdata.cxx 
b/vcl/source/pdf/pdfextoutdevdata.cxx
index 54272490d12a..9801f7ff6def 100644
--- a/vcl/source/pdf/pdfextoutdevdata.cxx
+++ b/vcl/source/pdf/pdfextoutdevdata.cxx
@@ -45,13 +45,13 @@ namespace {
 struct CreateNamedDest {
     OUString maDestName;
     MapMode maParaMapMode;
-    PDFWriter::DestAreaType mnParaDestAreaType;
+    pdf::PDFWriter::DestAreaType mnParaDestAreaType;
     tools::Rectangle maParaRect;
     sal_Int32 mnPage;
 };
 struct CreateDest {
     MapMode maParaMapMode;
-    PDFWriter::DestAreaType mnParaDestAreaType;
+    pdf::PDFWriter::DestAreaType mnParaDestAreaType;
     tools::Rectangle maParaRect;
     sal_Int32 mnPage;
 };
@@ -101,7 +101,7 @@ struct CreateNote {
 };
 
 struct SetPageTransition {
-    PDFWriter::PageTransition maParaPageTransition;
+    pdf::PDFWriter::PageTransition maParaPageTransition;
     sal_uInt32 mnMilliSec;
     sal_Int32 mnPage;
 };
@@ -116,10 +116,10 @@ struct BeginStructureElement { sal_Int32 mnId; };
 struct EndStructureElement{};
 struct SetCurrentStructureElement { sal_Int32 mnStructId; };
 struct SetStructureAttribute {
-    PDFWriter::StructAttribute mParaStructAttribute;
-    PDFWriter::StructAttributeValue mParaStructAttributeValue;
+    pdf::PDFWriter::StructAttribute mParaStructAttribute;
+    pdf::PDFWriter::StructAttributeValue mParaStructAttributeValue;
 };
-struct SetStructureAttributeNumerical { PDFWriter::StructAttribute 
mParaStructAttribute; sal_Int32 mnId; };
+struct SetStructureAttributeNumerical { pdf::PDFWriter::StructAttribute 
mParaStructAttribute; sal_Int32 mnId; };
 struct SetStructureBoundingBox { tools::Rectangle mRect; };
 struct SetStructureAnnotIds {
     ::std::vector<sal_Int32> annotIds;
@@ -127,7 +127,7 @@ struct SetStructureAnnotIds {
 struct SetActualText { OUString maText; };
 struct SetAlternateText { OUString maText; };
 struct CreateControl {
-    std::shared_ptr< PDFWriter::AnyWidget > mxControl;
+    std::shared_ptr< pdf::PDFWriter::AnyWidget > mxControl;
 };
 struct BeginGroup {};
 struct EndGroupGfxLink {
@@ -176,7 +176,7 @@ struct PDFLinkDestination
     tools::Rectangle               mRect;
     MapMode                 mMapMode;
     sal_Int32               mPageNr;
-    PDFWriter::DestAreaType mAreaType;
+    pdf::PDFWriter::DestAreaType mAreaType;
 };
 }
 
@@ -203,7 +203,7 @@ struct GlobalSyncData
     {
         mStructParents.push_back(0); // because PDFWriterImpl has a dummy root
     }
-    void PlayGlobalActions( PDFWriter& rWriter );
+    void PlayGlobalActions( pdf::PDFWriter& rWriter );
 };
 
 sal_Int32 GlobalSyncData::GetMappedId(sal_Int32 nLinkId)
@@ -224,7 +224,7 @@ sal_Int32 GlobalSyncData::GetMappedId(sal_Int32 nLinkId)
     return nLinkId;
 }
 
-void GlobalSyncData::PlayGlobalActions( PDFWriter& rWriter )
+void GlobalSyncData::PlayGlobalActions( pdf::PDFWriter& rWriter )
 {
     for (auto const& action : mActions)
     {
@@ -335,7 +335,7 @@ struct PageSyncData
     { mpGlobalData = pGlobal; }
 
     void PushAction( const OutputDevice& rOutDev, PageActionData eAct );
-    bool PlaySyncPageAct( PDFWriter& rWriter, sal_uInt32& rCurGDIMtfAction, 
const GDIMetaFile& rMtf, const PDFExtOutDevData& rOutDevData );
+    bool PlaySyncPageAct( pdf::PDFWriter& rWriter, sal_uInt32& 
rCurGDIMtfAction, const GDIMetaFile& rMtf, const PDFExtOutDevData& rOutDevData 
);
 };
 
 void PageSyncData::PushAction( const OutputDevice& rOutDev, PageActionData 
eAct )
@@ -351,7 +351,7 @@ void PageSyncData::PushAction( const OutputDevice& rOutDev, 
PageActionData eAct
         aSync.nIdx = 0x7fffffff;    // sync not possible
     mActions.emplace_back( std::move(aSync) );
 }
-bool PageSyncData::PlaySyncPageAct( PDFWriter& rWriter, sal_uInt32& 
rCurGDIMtfAction, const GDIMetaFile& rMtf, const PDFExtOutDevData& rOutDevData )
+bool PageSyncData::PlaySyncPageAct( pdf::PDFWriter& rWriter, sal_uInt32& 
rCurGDIMtfAction, const GDIMetaFile& rMtf, const PDFExtOutDevData& rOutDevData )
 {
     bool bRet = false;
     if ( !mActions.empty() && ( mActions.front().nIdx == rCurGDIMtfAction ) )
@@ -408,7 +408,7 @@ bool PageSyncData::PlaySyncPageAct( PDFWriter& rWriter, 
sal_uInt32& rCurGDIMtfAc
         }
         else if (std::holds_alternative<CreateControl>(aDataSync.eAct)) {
             const vcl::CreateControl& rCreateControl = 
std::get<CreateControl>(aDataSync.eAct);
-            std::shared_ptr< PDFWriter::AnyWidget > pControl( 
rCreateControl.mxControl );
+            std::shared_ptr< pdf::PDFWriter::AnyWidget > pControl( 
rCreateControl.mxControl );
             SAL_WARN_IF( !pControl, "vcl", "PageSyncData::PlaySyncPageAct: 
invalid widget!" );
             if ( pControl )
             {
@@ -614,7 +614,7 @@ void PDFExtOutDevData::SetIsExportNamedDestinations( const 
bool bExportNDests )
 {
     mbExportNDests = bExportNDests;
 }
-void PDFExtOutDevData::ResetSyncData(PDFWriter *const pWriter)
+void PDFExtOutDevData::ResetSyncData(pdf::PDFWriter *const pWriter)
 {
     if (pWriter != nullptr)
     {
@@ -630,11 +630,11 @@ void PDFExtOutDevData::ResetSyncData(PDFWriter *const 
pWriter)
     }
     *mpPageSyncData = PageSyncData( mpGlobalSyncData.get() );
 }
-bool PDFExtOutDevData::PlaySyncPageAct( PDFWriter& rWriter, sal_uInt32& rIdx, 
const GDIMetaFile& rMtf )
+bool PDFExtOutDevData::PlaySyncPageAct( pdf::PDFWriter& rWriter, sal_uInt32& 
rIdx, const GDIMetaFile& rMtf )
 {
     return mpPageSyncData->PlaySyncPageAct( rWriter, rIdx, rMtf, *this );
 }
-void PDFExtOutDevData::PlayGlobalActions( PDFWriter& rWriter )
+void PDFExtOutDevData::PlayGlobalActions( pdf::PDFWriter& rWriter )
 {
     mpGlobalSyncData->PlayGlobalActions( rWriter );
 }
@@ -646,7 +646,7 @@ void PDFExtOutDevData::PlayGlobalActions( PDFWriter& 
rWriter )
 sal_Int32 PDFExtOutDevData::CreateNamedDest(const OUString& sDestName,  const 
tools::Rectangle& rRect, sal_Int32 nPageNr )
 {
     mpGlobalSyncData->mActions.push_back(
-        vcl::CreateNamedDest{ sDestName, mrOutDev.GetMapMode(), 
PDFWriter::DestAreaType::XYZ, rRect, nPageNr == -1 ? mnPage : nPageNr } );
+        vcl::CreateNamedDest{ sDestName, mrOutDev.GetMapMode(), 
pdf::PDFWriter::DestAreaType::XYZ, rRect, nPageNr == -1 ? mnPage : nPageNr } );
 
     return mpGlobalSyncData->mCurId++;
 }
@@ -658,7 +658,7 @@ sal_Int32 PDFExtOutDevData::RegisterDest()
 
     return nLinkDestID;
 }
-void PDFExtOutDevData::DescribeRegisteredDest( sal_Int32 nDestId, const 
tools::Rectangle& rRect, sal_Int32 nPageNr, PDFWriter::DestAreaType eType )
+void PDFExtOutDevData::DescribeRegisteredDest( sal_Int32 nDestId, const 
tools::Rectangle& rRect, sal_Int32 nPageNr, pdf::PDFWriter::DestAreaType eType )
 {
     OSL_PRECOND( nDestId != -1, "PDFExtOutDevData::DescribeRegisteredDest: 
invalid destination Id!" );
     PDFLinkDestination aLinkDestination;
@@ -668,7 +668,7 @@ void PDFExtOutDevData::DescribeRegisteredDest( sal_Int32 
nDestId, const tools::R
     aLinkDestination.mAreaType = eType;
     mpGlobalSyncData->mFutureDestinations[ nDestId ] = 
std::move(aLinkDestination);
 }
-sal_Int32 PDFExtOutDevData::CreateDest( const tools::Rectangle& rRect, 
sal_Int32 nPageNr, PDFWriter::DestAreaType eType )
+sal_Int32 PDFExtOutDevData::CreateDest( const tools::Rectangle& rRect, 
sal_Int32 nPageNr, pdf::PDFWriter::DestAreaType eType )
 {
     mpGlobalSyncData->mActions.push_back(
         vcl::CreateDest{ mrOutDev.GetMapMode(), eType, rRect, nPageNr == -1 ? 
mnPage : nPageNr } );
@@ -737,7 +737,7 @@ sal_Int32 PDFExtOutDevData::CreateNote(const 
tools::Rectangle& rRect,
         mrOutDev.GetMapMode(), rNote, rRect, rPopupRect, nPageNr == -1 ? 
mnPage : nPageNr });
     return mpGlobalSyncData->mCurId++;
 }
-void PDFExtOutDevData::SetPageTransition( PDFWriter::PageTransition eType, 
sal_uInt32 nMilliSec )
+void PDFExtOutDevData::SetPageTransition( pdf::PDFWriter::PageTransition 
eType, sal_uInt32 nMilliSec )
 {
     mpGlobalSyncData->mActions.push_back( vcl::SetPageTransition{ eType, 
nMilliSec, mnPage } );
 }
@@ -812,11 +812,11 @@ sal_Int32 PDFExtOutDevData::GetCurrentStructureElement() 
const
     return mpGlobalSyncData->mCurrentStructElement;
 }
 
-void PDFExtOutDevData::SetStructureAttribute( PDFWriter::StructAttribute 
eAttr, PDFWriter::StructAttributeValue eVal )
+void PDFExtOutDevData::SetStructureAttribute( pdf::PDFWriter::StructAttribute 
eAttr, pdf::PDFWriter::StructAttributeValue eVal )
 {
     mpPageSyncData->PushAction( mrOutDev, vcl::SetStructureAttribute{ eAttr, 
eVal } );
 }
-void PDFExtOutDevData::SetStructureAttributeNumerical( 
PDFWriter::StructAttribute eAttr, sal_Int32 nValue )
+void PDFExtOutDevData::SetStructureAttributeNumerical( 
pdf::PDFWriter::StructAttribute eAttr, sal_Int32 nValue )
 {
     mpPageSyncData->PushAction( mrOutDev, vcl::SetStructureAttributeNumerical 
{ eAttr, nValue } );
 }
@@ -839,7 +839,7 @@ void PDFExtOutDevData::SetAlternateText( const OUString& 
rText )
     mpPageSyncData->PushAction( mrOutDev, vcl::SetAlternateText{ rText } );
 }
 
-void PDFExtOutDevData::CreateControl( const PDFWriter::AnyWidget& rControlType 
)
+void PDFExtOutDevData::CreateControl( const pdf::PDFWriter::AnyWidget& 
rControlType )
 {
     mpPageSyncData->PushAction(mrOutDev, vcl::CreateControl{ 
rControlType.Clone() });
 }
diff --git a/vcl/unx/generic/print/genprnpsp.cxx 
b/vcl/unx/generic/print/genprnpsp.cxx
index e078fe9c6dc5..73d83ab89220 100644
--- a/vcl/unx/generic/print/genprnpsp.cxx
+++ b/vcl/unx/generic/print/genprnpsp.cxx
@@ -798,12 +798,12 @@ bool PspSalPrinter::StartJob( const OUString* 
i_pFileName, const OUString& i_rJo
     i_rController.jobStarted();
 
     // setup PDFWriter context
-    vcl::PDFWriter::PDFWriterContext aContext;
-    aContext.Version            = vcl::PDFWriter::PDFVersion::PDF_1_4;
+    vcl::pdf::PDFWriter::PDFWriterContext aContext;
+    aContext.Version            = vcl::pdf::PDFWriter::PDFVersion::PDF_1_4;
     aContext.Tagged             = false;
     aContext.DocumentLocale     = 
Application::GetSettings().GetLanguageTag().getLocale();
     aContext.ColorMode          = 
i_rController.getPrinter()->GetPrinterOptions().IsConvertToGreyscales()
-    ? vcl::PDFWriter::DrawGreyscale : vcl::PDFWriter::DrawColor;
+    ? vcl::pdf::PDFWriter::DrawGreyscale : vcl::pdf::PDFWriter::DrawColor;
 
     // prepare doc info
     aContext.DocumentInfo.Title              = i_rJobName;
@@ -811,10 +811,10 @@ bool PspSalPrinter::StartJob( const OUString* 
i_pFileName, const OUString& i_rJo
     aContext.DocumentInfo.Producer           = i_rAppName;
 
     // define how we handle metafiles in PDFWriter
-    vcl::PDFWriter::PlayMetafileContext aMtfContext;
+    vcl::pdf::PDFWriter::PlayMetafileContext aMtfContext;
     aMtfContext.m_bOnlyLosslessCompression = true;
 
-    std::shared_ptr<vcl::PDFWriter> xWriter;
+    std::shared_ptr<vcl::pdf::PDFWriter> xWriter;
     std::vector< PDFPrintFile > aPDFFiles;
     VclPtr<Printer> xPrinter( i_rController.getPrinter() );
     int nAllPages = i_rController.getFilteredPageCount();
@@ -882,12 +882,12 @@ bool PspSalPrinter::StartJob( const OUString* 
i_pFileName, const OUString& i_rJo
                 aContext.URL = aPDFUrl;
 
                 // create and initialize PDFWriter
-                xWriter = std::make_shared<vcl::PDFWriter>( aContext, 
uno::Reference< beans::XMaterialHolder >() );
+                xWriter = std::make_shared<vcl::pdf::PDFWriter>( aContext, 
uno::Reference< beans::XMaterialHolder >() );
             }
 
             xWriter->NewPage( TenMuToPt( aNewParm.maPageSize.Width() ),
                               TenMuToPt( aNewParm.maPageSize.Height() ),
-                              vcl::PDFWriter::Orientation::Portrait );
+                              vcl::pdf::PDFWriter::Orientation::Portrait );
 
             xWriter->PlayMetafile( aPageFile, aMtfContext );
         }

Reply via email to
diff --git a/sw/source/core/text/EnhancedPDFExportHelper.cxx 
b/sw/source/core/text/EnhancedPDFExportHelper.cxx
index 05dd9b38ea30..99041e54b38a 100644
--- a/sw/source/core/text/EnhancedPDFExportHelper.cxx
+++ b/sw/source/core/text/EnhancedPDFExportHelper.cxx
@@ -712,7 +712,7 @@ namespace {
         if (aIter != rLinkIdMap.end())
         {
             sal_Int32 nLinkId = (*aIter).second;
-            
rPDFExtOutDevData.SetStructureAttributeNumerical(vcl::PDFWriter::LinkAnnotation,
 nLinkId);
+            
rPDFExtOutDevData.SetStructureAttributeNumerical(vcl::pdf::PDFWriter::LinkAnnotation,
 nLinkId);
         }
     }
 }
@@ -727,7 +727,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
      */
     if ( mpFrameInfo )
     {
-        vcl::PDFWriter::StructAttributeValue eVal;
+        vcl::pdf::PDFWriter::StructAttributeValue eVal;
         const SwFrame* pFrame = &mpFrameInfo->mrFrame;
         SwRectFnSet aRectFnSet(pFrame);
 
@@ -775,7 +775,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                 break;
 
             case vcl::pdf::StructElement::TableHeader:
-                
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Scope, 
vcl::PDFWriter::Column);
+                
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Scope, 
vcl::pdf::PDFWriter::Column);
                 [[fallthrough]];
             case vcl::pdf::StructElement::TableData:
                 bPlacement =
@@ -832,11 +832,11 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                 if (pFrame->IsHeaderFrame() || pFrame->IsFooterFrame())
                 {
                     // ISO 14289-1:2014, Clause: 7.8
-                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Type, 
vcl::PDFWriter::Pagination);
-                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::Subtype,
+                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Type, 
vcl::pdf::PDFWriter::Pagination);
+                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::Subtype,
                         pFrame->IsHeaderFrame()
-                           ? vcl::PDFWriter::Header
-                           : vcl::PDFWriter::Footer);
+                           ? vcl::pdf::PDFWriter::Header
+                           : vcl::pdf::PDFWriter::Footer);
                 }
             break;
 
@@ -860,50 +860,50 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             eVal = vcl::pdf::StructElement::TableHeader == eType
                 || vcl::pdf::StructElement::TableData == eType
                 || bIsFigureInline
-                       ? vcl::PDFWriter::Inline
-                       : vcl::PDFWriter::Block;
+                       ? vcl::pdf::PDFWriter::Inline
+                       : vcl::pdf::PDFWriter::Block;
 
-            mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::Placement, eVal );
+            mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::Placement, eVal );
         }
 
         if ( bWritingMode )
         {
             eVal =  pFrame->IsVertical() ?
-                    vcl::PDFWriter::TbRl :
+                    vcl::pdf::PDFWriter::TbRl :
                     pFrame->IsRightToLeft() ?
-                    vcl::PDFWriter::RlTb :
-                    vcl::PDFWriter::LrTb;
+                    vcl::pdf::PDFWriter::RlTb :
+                    vcl::pdf::PDFWriter::LrTb;
 
-            if ( vcl::PDFWriter::LrTb != eVal )
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::WritingMode, eVal );
+            if ( vcl::pdf::PDFWriter::LrTb != eVal )
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::WritingMode, eVal );
         }
 
         if ( bSpaceBefore )
         {
             nVal = aRectFnSet.GetTopMargin(*pFrame);
             if ( 0 != nVal )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::SpaceBefore, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::SpaceBefore, nVal );
         }
 
         if ( bSpaceAfter )
         {
             nVal = aRectFnSet.GetBottomMargin(*pFrame);
             if ( 0 != nVal )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::SpaceAfter, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::SpaceAfter, nVal );
         }
 
         if ( bStartIndent )
         {
             nVal = aRectFnSet.GetLeftMargin(*pFrame);
             if ( 0 != nVal )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::StartIndent, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::StartIndent, nVal );
         }
 
         if ( bEndIndent )
         {
             nVal = aRectFnSet.GetRightMargin(*pFrame);
             if ( 0 != nVal )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::EndIndent, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::EndIndent, nVal );
         }
 
         if ( bTextIndent )
@@ -913,7 +913,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                 static_cast<const 
SwTextFrame*>(pFrame)->GetTextNodeForParaProps()->GetSwAttrSet().GetFirstLineIndent());
             nVal = rFirstLine.ResolveTextFirstLineOffset({});
             if ( 0 != nVal )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::TextIndent, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::TextIndent, nVal );
         }
 
         if ( bTextAlign )
@@ -926,12 +926,12 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                    (!pFrame->IsRightToLeft() && SvxAdjust::Right == nAdjust) ) 
)
             {
                 eVal = SvxAdjust::Block == nAdjust ?
-                       vcl::PDFWriter::Justify :
+                       vcl::pdf::PDFWriter::Justify :
                        SvxAdjust::Center == nAdjust ?
-                       vcl::PDFWriter::Center :
-                       vcl::PDFWriter::End;
+                       vcl::pdf::PDFWriter::Center :
+                       vcl::pdf::PDFWriter::End;
 
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::TextAlign, eVal );
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::TextAlign, eVal );
             }
         }
 
@@ -958,13 +958,13 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
         if ( bWidth )
         {
             nVal = aRectFnSet.GetWidth(pFrame->getFrameArea());
-            mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::Width, nVal );
+            mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::Width, nVal );
         }
 
         if ( bHeight )
         {
             nVal = aRectFnSet.GetHeight(pFrame->getFrameArea());
-            mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::Height, nVal );
+            mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::Height, nVal );
         }
 
         if ( bBox )
@@ -986,7 +986,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                 const SwCellFrame* pThisCell = static_cast<const 
SwCellFrame*>(pFrame);
                 nVal =  pThisCell->GetTabBox()->getRowSpan();
                 if ( nVal > 1 )
-                    mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::RowSpan, nVal );
+                    mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::RowSpan, nVal );
 
                 // calculate colspan:
                 const SwTabFrame* pTabFrame = pThisCell->FindTabFrame();
@@ -1006,7 +1006,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
                 {
                     nVal = std::distance( aLeftIter, aRightIter );
                     if ( nVal > 1 )
-                        mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::ColSpan, nVal );
+                        mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::ColSpan, nVal );
                 }
             }
         }
@@ -1062,44 +1062,44 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             case vcl::pdf::StructElement::RT:
                 {
                     SwRubyPortion const*const pRuby(static_cast<SwRubyPortion 
const*>(pPor));
-                    vcl::PDFWriter::StructAttributeValue nAlign = {};
+                    vcl::pdf::PDFWriter::StructAttributeValue nAlign = {};
                     switch (pRuby->GetAdjustment())
                     {
                         case text::RubyAdjust_LEFT:
-                            nAlign = vcl::PDFWriter::RStart;
+                            nAlign = vcl::pdf::PDFWriter::RStart;
                             break;
                         case text::RubyAdjust_CENTER:
-                            nAlign = vcl::PDFWriter::RCenter;
+                            nAlign = vcl::pdf::PDFWriter::RCenter;
                             break;
                         case text::RubyAdjust_RIGHT:
-                            nAlign = vcl::PDFWriter::REnd;
+                            nAlign = vcl::pdf::PDFWriter::REnd;
                             break;
                         case text::RubyAdjust_BLOCK:
-                            nAlign = vcl::PDFWriter::RJustify;
+                            nAlign = vcl::pdf::PDFWriter::RJustify;
                             break;
                         case text::RubyAdjust_INDENT_BLOCK:
-                            nAlign = vcl::PDFWriter::RDistribute;
+                            nAlign = vcl::pdf::PDFWriter::RDistribute;
                             break;
                         default:
                             assert(false);
                             break;
                     }
-                    ::std::optional<vcl::PDFWriter::StructAttributeValue> oPos;
+                    ::std::optional<vcl::pdf::PDFWriter::StructAttributeValue> 
oPos;
                     switch (pRuby->GetRubyPosition())
                     {
                         case RubyPosition::ABOVE:
-                            oPos = vcl::PDFWriter::RBefore;
+                            oPos = vcl::pdf::PDFWriter::RBefore;
                             break;
                         case RubyPosition::BELOW:
-                            oPos = vcl::PDFWriter::RAfter;
+                            oPos = vcl::pdf::PDFWriter::RAfter;
                             break;
                         case RubyPosition::RIGHT:
                             break; // no such thing???
                     }
-                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::RubyAlign, nAlign);
+                    
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::RubyAlign, 
nAlign);
                     if (oPos)
                     {
-                        
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::RubyPosition, *oPos);
+                        
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::RubyPosition, 
*oPos);
                     }
                 }
                 break;
@@ -1133,20 +1133,20 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             if ( 0 != nVal )
             {
                 nVal = nVal * pPor->Height() / 100;
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::BaselineShift, nVal );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::BaselineShift, nVal );
             }
         }
 
         if ( bTextDecorationType )
         {
             if ( LINESTYLE_NONE    != rInf.GetFont()->GetUnderline() )
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::Underline );
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::TextDecorationType, vcl::pdf::PDFWriter::Underline );
             if ( LINESTYLE_NONE    != rInf.GetFont()->GetOverline() )
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::Overline );
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::TextDecorationType, vcl::pdf::PDFWriter::Overline );
             if ( STRIKEOUT_NONE    != rInf.GetFont()->GetStrikeout() )
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::LineThrough );
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::TextDecorationType, vcl::pdf::PDFWriter::LineThrough );
             if ( FontEmphasisMark::NONE != rInf.GetFont()->GetEmphasisMark() )
-                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::PDFWriter::TextDecorationType, vcl::PDFWriter::Overline );
+                mpPDFExtOutDevData->SetStructureAttribute( 
vcl::pdf::PDFWriter::TextDecorationType, vcl::pdf::PDFWriter::Overline );
         }
 
         if ( bLanguage )
@@ -1156,7 +1156,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             const LanguageType 
nDefaultLang(mpPDFExtOutDevData->GetSwPDFState()->m_eLanguageDefault);
 
             if ( nDefaultLang != nCurrentLanguage )
-                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::PDFWriter::Language, static_cast<sal_uInt16>(nCurrentLanguage) );
+                mpPDFExtOutDevData->SetStructureAttributeNumerical( 
vcl::pdf::PDFWriter::Language, static_cast<sal_uInt16>(nCurrentLanguage) );
         }
 
         if ( bLinkAttribute )
@@ -1178,7 +1178,7 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             if (aIter != rNoteIdMap.end())
             {
                 sal_Int32 nNoteId = (*aIter).second;
-                
mpPDFExtOutDevData->SetStructureAttributeNumerical(vcl::PDFWriter::NoteAnnotation,
+                
mpPDFExtOutDevData->SetStructureAttributeNumerical(vcl::pdf::PDFWriter::NoteAnnotation,
                                                                    nNoteId);
             }
         }
@@ -1194,39 +1194,39 @@ void 
SwTaggedPDFHelper::SetAttributes(vcl::pdf::StructElement eType)
             switch (rFormat.GetNumberingType())
             {
                 case css::style::NumberingType::CHARS_UPPER_LETTER:
-                    return vcl::PDFWriter::UpperAlpha;
+                    return vcl::pdf::PDFWriter::UpperAlpha;
                 case css::style::NumberingType::CHARS_LOWER_LETTER:
-                    return vcl::PDFWriter::LowerAlpha;
+                    return vcl::pdf::PDFWriter::LowerAlpha;
                 case css::style::NumberingType::ROMAN_UPPER:
-                    return vcl::PDFWriter::UpperRoman;
+                    return vcl::pdf::PDFWriter::UpperRoman;
                 case css::style::NumberingType::ROMAN_LOWER:
-                    return vcl::PDFWriter::LowerRoman;
+                    return vcl::pdf::PDFWriter::LowerRoman;
                 case css::style::NumberingType::ARABIC:
-                    return vcl::PDFWriter::Decimal;
+                    return vcl::pdf::PDFWriter::Decimal;
                 case css::style::NumberingType::CHAR_SPECIAL:
                     switch (rFormat.GetBulletChar())
                     {
                         case u'\u2022': case u'\uE12C': case u'\uE01E': case 
u'\uE437':
-                            return vcl::PDFWriter::Disc;
+                            return vcl::pdf::PDFWriter::Disc;
                         case u'\u2218': case u'\u25CB': case u'\u25E6':
-                            return vcl::PDFWriter::Circle;
+                            return vcl::pdf::PDFWriter::Circle;
                         case u'\u25A0': case u'\u25AA': case u'\uE00A':
-                            return vcl::PDFWriter::Square;
+                            return vcl::pdf::PDFWriter::Square;
                         default:
-                            return vcl::PDFWriter::NONE;
+                            return vcl::pdf::PDFWriter::NONE;
                     }
                 default: // the other 50 types
-                    return vcl::PDFWriter::NONE;
+                    return vcl::pdf::PDFWriter::NONE;
             }
         };
 
         // Note: for every level, BeginNumberedListStructureElements() produces
         // a separate List element, so even though in PDF this is limited to
         // the whole List we can just export the current level here.
-        vcl::PDFWriter::StructAttributeValue const value(
+        vcl::pdf::PDFWriter::StructAttributeValue const value(
                 ToPDFListNumbering(pNumRule->Get(rNode.GetActualListLevel())));
         // ISO 14289-1:2014, Clause: 7.6
-        
mpPDFExtOutDevData->SetStructureAttribute(vcl::PDFWriter::ListNumbering, value);
+        
mpPDFExtOutDevData->SetStructureAttribute(vcl::pdf::PDFWriter::ListNumbering, 
value);
     }
 }
 
@@ -1432,7 +1432,7 @@ void SwTaggedPDFHelper::BeginBlockStructureElements()
 
             // Footnote frame: Note
 
             // Note: vcl::PDFWriter::Note is actually a ILSE. Nevertheless
             // we treat it like a grouping element!
             nPDFType = sal_uInt16(vcl::pdf::StructElement::Note);
             aPDFType = aNoteString;
@@ -1432,7 +1432,7 @@ void SwTaggedPDFHelper::BeginBlockStructureElements()
             // Footnote frame: Note
 
-            // Note: vcl::PDFWriter::Note is actually a ILSE. Nevertheless
+            // Note: vcl::pdf::PDFWriter::Note is actually a ILSE. Nevertheless
             // we treat it like a grouping element!
             nPDFType = sal_uInt16(vcl::pdf::StructElement::Note);